@@ -19,12 +19,16 @@
 #include <iostream>
 #include <QRegExp>
 #include <QMessageService>
+#include <QSqlQuery>
+
 using namespace QtMobility;
 
 SmsSender::SmsSender(int argc, char *argv[]) :
         QCoreApplication(argc,argv)
 {
+    m_Db = NULL;
     m_LogFile = NULL;
+    m_Save = true;
     m_Argc = argc - 1;
     for (int i=1; i<argc; i++)
         m_Argv.append(argv[i]);
@@ -36,6 +40,9 @@ SmsSender::~SmsSender()
         m_LogFile->close();
         delete m_LogFile;
     }
+
+    if (m_Db != NULL)
+        m_Db->close();
 }
 
 void SmsSender::consoleOutput(QString output, bool newline)
@@ -60,6 +67,9 @@ void SmsSender::printUsage()
     consoleOutput("  -c         : compose message with conversation");
     consoleOutput("  -l logfile : log pnatd messages to logfile");
     consoleOutput("               This option is useless if used with -c");
+    consoleOutput("  -s         : don't save message in the sent folder");
+    consoleOutput("               This option is useless if used with -c");
+
 }
 
 int SmsSender::exec()
@@ -88,6 +98,8 @@ int SmsSender::exec()
                 currArg = SmsSender::argLog;
             else if (param == "-c")
                 m_Compose = true;
+            else if (param == "-s")
+                m_Save = false;
             else{
                 consoleOutput(QString("ERR: unrecognized argument: %1").arg(param));
                 return errArguments;
@@ -95,7 +107,10 @@ int SmsSender::exec()
         }else{
             switch (currArg){
                 case SmsSender::argNumber:
-                    numbers.append(param.split(":"));
+                    foreach (QString num, param.split(":")){
+                        if (!numbers.contains(num))
+                            numbers.append(num);
+                    }
                     break;
                 case SmsSender::argText:
                     message = param;
@@ -130,6 +145,15 @@ int SmsSender::exec()
     }
 
     if (ok){
+        m_Db = new QSqlDatabase();
+        *m_Db = QSqlDatabase::addDatabase( "QSQLITE" );
+        m_Db->setDatabaseName("/home/user/.rtcom-eventlogger/el-v1.db");
+        if (!m_Db->open()){
+            consoleOutput("WARNING: error opening events database");
+            delete m_Db;
+            m_Db = NULL;
+        }
+
         QStringList messageBlocks;
         if (m_Compose || message.length() <= 160)
             messageBlocks.append(message);
@@ -239,8 +263,13 @@ bool SmsSender::send(QString number, QString messageText)
         res = writeCmd(pty, QString("%1").arg(QChar(26)).toLatin1(), "OK", -1);
         if (!res)
             consoleOutput("FAILED");
-        else
+        else{
             consoleOutput("OK");
+            if (m_Save){
+                if (m_Db != NULL && !saveMsgToSentFolder(number, messageText))
+                    consoleOutput("WARNING: Failed to save sent sms");
+            }
+        }
     }
     delete pty;
     return res;
@@ -272,3 +301,28 @@ bool SmsSender::writeCmd(Pty* p, QString cmd, QString okReply, int msectimeout)
         return true;
     }
 }
+
+bool SmsSender::saveMsgToSentFolder(QString number, QString message)
+{    
+    //This isn't the best way, it should really be replaced with some API.
+    //ATM QtMobility doesn't have a method to save a message in a folder.
+    message.replace("'", "''");
+    QString partNumber = number.right(7);
+    QString sql = QString("insert into Events (service_id, event_type_id, storage_time, start_time, end_time, is_read, flags, \
+                                               bytes_sent, bytes_received, local_uid, local_name, remote_uid, free_text, group_uid, outgoing) \
+                           values (3, 7, strftime('%s', 'now'), strftime('%s', 'now'), 0, 1, 0, 0, 0, 'ring/tel/ring', '<SelfHandle>', '%1', '%2', '%3', 1)")
+                           .arg(number)
+                           .arg(message)
+                           .arg(partNumber);
+    QSqlQuery qry;
+    if (!qry.prepare(sql))
+        return false;
+
+    if (!qry.exec())
+        return false;
+
+    //QMessageService service;
+    //service.exportUpdates(QMessageAccount::defaultAccount(QMessage::Sms));
+
+    return true;
+}
