@@ -21,6 +21,7 @@
 #include <QCoreApplication>
 #include <QStringList>
 #include <QFile>
+#include <QSqlDatabase>
 #include "ptyi.h"
 
 #define COMMAND_TIMEOUT 500
@@ -39,6 +40,7 @@ private:
         argText,
         argCompose,
         argLog,
+        argDontSave,
     };
 
     enum errors{
@@ -48,9 +50,11 @@ private:
         errLogfileOpenFailed = -3,
     };
 
+    QSqlDatabase* m_Db;
     int m_Argc;
     QStringList m_Argv;
     bool m_Compose;
+    bool m_Save;
     QFile* m_LogFile;
 
     void consoleOutput(QString output, bool newline=true);
@@ -61,6 +65,7 @@ private:
     bool send(QString number, QString message);
     bool writeCmd(Pty* p, QString cmd, QString okReply, int msectimeout=COMMAND_TIMEOUT);
 
+    bool saveMsgToSentFolder(QString number, QString message);
 };
 
 #endif // SMSSENDER_H
